@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -35,9 +35,7 @@ ThemeEditorMainWindow::ThemeEditorMainWindow()
     readConfig();
 }
 
-ThemeEditorMainWindow::~ThemeEditorMainWindow()
-{
-}
+ThemeEditorMainWindow::~ThemeEditorMainWindow() = default;
 
 void ThemeEditorMainWindow::writeConfig()
 {
